@@ -1,8 +1,6 @@
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import Optional, Union, List
 
-from brain_brew.representation.build_config.representation_base import RepresentationBase
-
 
 @dataclass
 class SharedBaseNotes:
