@@ -2,9 +2,9 @@ import logging
 from dataclasses import dataclass, field
 from typing import List, Dict
 
-from brain_brew.representation.build_config.representation_base import RepresentationBase
-from brain_brew.representation.configuration.csv_file_mapping import FileMapping
-from brain_brew.representation.configuration.note_model_mapping import NoteModelMapping
+from brain_brew.configuration.representation_base import RepresentationBase
+from brain_brew.transformers.file_mapping import FileMapping
+from brain_brew.transformers.note_model_mapping import NoteModelMapping
 
 
 @dataclass
@@ -22,15 +22,12 @@ class SharedBaseCsvs:
             return list(map(FileMapping.from_repr, self.file_mappings))
 
     file_mappings: List[FileMapping]
-    note_model_mappings_to_read: List[NoteModelMapping.Representation]
-    note_model_mappings: Dict[str, NoteModelMapping] = field(init=False)
+    note_model_mappings: Dict[str, NoteModelMapping]
 
-    def setup_note_model_mappings(self):
-        def map_nmm(nmm_to_map: str):
-            nmm = NoteModelMapping.from_repr(nmm_to_map)
-            return nmm.get_note_model_mapping_dict()
-
-        self.note_model_mappings = dict(*map(map_nmm, self.note_model_mappings_to_read))
+    @classmethod
+    def map_nmm(cls, nmm_to_map):
+        nmm = NoteModelMapping.from_repr(nmm_to_map)
+        return nmm.get_note_model_mapping_dict()
 
     def verify_contents(self):
         errors = []
@@ -41,18 +38,11 @@ class SharedBaseCsvs:
             except KeyError as e:
                 errors.append(e)
 
-        for fm in self.file_mappings:
-            # Check all necessary key values are present
-            try:
-                fm.verify_contents()
-            except KeyError as e:
-                errors.append(e)
-
-            # Check all referenced note models have a mapping
-            for csv_map in self.file_mappings:
-                for nm in csv_map.get_used_note_model_names():
-                    if nm not in self.note_model_mappings.keys():
-                        errors.append(f"Missing Note Model Map for {nm}")
+        # Check all referenced note models have a mapping
+        for csv_map in self.file_mappings:
+            for nm in csv_map.get_used_note_model_names():
+                if nm not in self.note_model_mappings.keys():
+                    errors.append(f"Missing Note Model Map for {nm}")
 
         # Check each of the Csvs (or their derivatives) contain all the necessary columns for their stated note model
         for cfm in self.file_mappings:
@@ -63,7 +53,7 @@ class SharedBaseCsvs:
                                            key in note_model_names]
             for nm_map in referenced_note_models_maps:
                 for holder in nm_map.note_models.values():
-                    missing_columns = [col for col in holder.deck_part.field_names_lowercase if
+                    missing_columns = [col for col in holder.part.field_names_lowercase if
                                        col not in nm_map.csv_headers_map_to_note_fields(available_columns)]
                     if missing_columns:
                         logging.warning(f"Csvs are missing columns from {holder.part_id} {missing_columns}")
